@@ -105,9 +105,6 @@ public:
   bool IsSet(const char* name) const;
   bool IsOn(const char* name) const;
 
-  //! Set all the variables
-  int SetCMakeRoot();
-
   //! Set the logger
   void SetLogger(cmCPackLog* log) { this->Logger = log; }
 
@@ -160,9 +157,10 @@ protected:
    * CPack specific generator may mangle CPACK_PACKAGE_FILE_NAME
    * with CPACK_COMPONENT_xxxx_<NAME>_DISPLAY_NAME if
    * CPACK_<GEN>_USE_DISPLAY_NAME_IN_FILENAME is ON.
-   * @param[in] initialPackageFileName
-   * @param[in] groupOrComponentName
-   * @param[in] isGroupName
+   * @param[in] initialPackageFileName the initial package name to be mangled
+   * @param[in] groupOrComponentName the name of the group/component
+   * @param[in] isGroupName true if previous name refers to a group,
+   *            false otherwise
    */
   virtual std::string GetComponentPackageFileName(
       const std::string& initialPackageFileName,
@@ -172,7 +170,7 @@ protected:
   /**
    * Package the list of files and/or components which
    * has been prepared by the beginning of DoPackage.
-   * @pre @ref toplevel has been filled-in
+   * @pre the @ref toplevel has been filled-in
    * @pre the list of file @ref files has been populated
    * @pre packageFileNames contains at least 1 entry
    * @post packageFileNames may have been updated and contains
@@ -284,10 +282,6 @@ protected:
    */
   std::vector<std::string> files;
 
-  std::string CPackSelf;
-  std::string CMakeSelf;
-  std::string CMakeRoot;
-
   std::map<std::string, cmCPackInstallationType> InstallationTypes;
   /**
    * The set of components.
