@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc.
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmCTestMemCheckHandler.h,v $
-  Language:  C++
-  Date:      $Date: 2006/03/10 20:03:09 $
-  Version:   $Revision: 1.3 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc. All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 
 #ifndef cmCTestMemCheckHandler_h
 #define cmCTestMemCheckHandler_h
@@ -30,18 +25,19 @@ class cmMakefile;
  */
 class cmCTestMemCheckHandler : public cmCTestTestHandler
 {
+  friend class cmCTestRunTest;
 public:
   cmTypeMacro(cmCTestMemCheckHandler, cmCTestTestHandler);
 
   void PopulateCustomVectors(cmMakefile *mf);
-  
+
   cmCTestMemCheckHandler();
 
   void Initialize();
 protected:
   virtual int PreProcessHandler();
   virtual int PostProcessHandler();
-  virtual void GenerateTestCommand(std::vector<const char*>& args);
+  virtual void GenerateTestCommand(std::vector<std::string>& args, int test);
 
 private:
 
@@ -51,7 +47,7 @@ private:
     PURIFY,
     BOUNDS_CHECKER
   };
-
+public:
   enum { // Memory faults
     ABR = 0,
     ABW,
@@ -77,7 +73,7 @@ private:
     UMR,
     NO_MEMORY_FAULT
   };
-  
+private:
   enum { // Program statuses
     NOT_RUN = 0,
     TIMEOUT,
@@ -90,10 +86,11 @@ private:
     BAD_COMMAND,
     COMPLETED
   };
-
+  std::string              BoundsCheckerDPBDFile;
+  std::string              BoundsCheckerXMLFile;
   std::string              MemoryTester;
-  std::vector<cmStdString> MemoryTesterOptionsParsed;
-  std::string              MemoryTesterOptions;
+  std::vector<cmStdString> MemoryTesterDynamicOptions;
+  std::vector<cmStdString> MemoryTesterOptions;
   int                      MemoryTesterStyle;
   std::string              MemoryTesterOutputFile;
   int                      MemoryTesterGlobalResults[NO_MEMORY_FAULT];
@@ -112,13 +109,25 @@ private:
   //! Parse Valgrind/Purify/Bounds Checker result out of the output
   //string. After running, log holds the output and results hold the
   //different memmory errors.
-  bool ProcessMemCheckOutput(const std::string& str, 
+  bool ProcessMemCheckOutput(const std::string& str,
                              std::string& log, int* results);
-  bool ProcessMemCheckValgrindOutput(const std::string& str, 
+  bool ProcessMemCheckValgrindOutput(const std::string& str,
                                      std::string& log, int* results);
-  bool ProcessMemCheckPurifyOutput(const std::string& str, 
+  bool ProcessMemCheckPurifyOutput(const std::string& str,
                                    std::string& log, int* results);
+  bool ProcessMemCheckBoundsCheckerOutput(const std::string& str,
+                                          std::string& log, int* results);
 
+  void PostProcessPurifyTest(cmCTestTestResult& res, int test);
+  void PostProcessBoundsCheckerTest(cmCTestTestResult& res, int test);
+  void PostProcessValgrindTest(cmCTestTestResult& res, int test);
+
+  ///! append MemoryTesterOutputFile to the test log
+  void appendMemTesterOutput(cmCTestTestHandler::cmCTestTestResult& res,
+                             int test);
+
+  ///! generate the output filename for the given test index
+  cmStdString testOutputFileName(int test);
 };
 
 #endif
