@@ -19,15 +19,16 @@
 /** \class cmCTestMultiProcessHandler
  * \brief run parallel ctest
  *
- * cmCTestMultiProcessHandler 
+ * cmCTestMultiProcessHandler
  */
-class cmCTestMultiProcessHandler 
+class cmCTestMultiProcessHandler
 {
+  friend class TestComparator;
 public:
   struct TestSet : public std::set<int> {};
   struct TestMap : public std::map<int, TestSet> {};
-  struct TestCostMap : public std::map<float, TestSet> {};
-  struct PropertiesMap : public 
+  struct TestList : public std::vector<int> {};
+  struct PropertiesMap : public
      std::map<int, cmCTestTestHandler::cmCTestTestProperties*> {};
 
   cmCTestMultiProcessHandler();
@@ -38,6 +39,7 @@ public:
   void SetParallelLevel(size_t);
   virtual void RunTests();
   void PrintTestList();
+  void PrintLabels();
 
   void SetPassFailVectors(std::vector<cmStdString>* passed,
                           std::vector<cmStdString>* failed)
@@ -70,6 +72,12 @@ protected:
   int SearchByName(std::string name);
 
   void CreateTestCostList();
+
+  void GetAllTestDependencies(int test, TestList& dependencies);
+  void CreateSerialTestCostList();
+
+  void CreateParallelTestCostList();
+
   // Removes the checkpoint file
   void MarkFinished();
   void EraseTest(int index);
@@ -88,7 +96,7 @@ protected:
   void UnlockResources(int index);
   // map from test number to set of depend tests
   TestMap Tests;
-  TestCostMap TestCosts;
+  TestList SortedTests;
   //Total number of tests we'll be running
   size_t Total;
   //Number of tests that are complete
@@ -109,6 +117,7 @@ protected:
   std::set<cmCTestRunTest*> RunningTests;  // current running tests
   cmCTestTestHandler * TestHandler;
   cmCTest* CTest;
+  bool HasCycles;
 };
 
 #endif
