@@ -97,7 +97,7 @@ public:
   static void SleepInSeconds(unsigned int secondsToWait);
   void UpdateElapsedTime();
 
-  /** 
+  /**
    * Return the time remaianing that the script is allowed to run in
    * seconds if the user has set the variable CTEST_TIME_LIMIT. If that has
    * not been set it returns 1e7 seconds
@@ -110,7 +110,6 @@ public:
   void Initialize();
 
   void CreateCMake();
-  void GetCommandDocumentation(std::vector<cmDocumentationEntry>& v) const;
   cmake* GetCMake() { return this->CMake;}
 private:
   // reads in a script
@@ -136,6 +135,9 @@ private:
   // Add ctest command
   void AddCTestCommand(cmCTestCommand* command);
 
+  // Try to remove the binary directory once
+  static bool TryToRemoveBinaryDirectoryOnce(const std::string& directoryPath);
+
   std::vector<cmStdString> ConfigurationScripts;
   std::vector<bool> ScriptProcessScope;
 
