@@ -15,9 +15,9 @@
 inline int ctrl(int z)
 {
     return (z&037);
-} 
+}
 
-cmCursesStringWidget::cmCursesStringWidget(int width, int height, 
+cmCursesStringWidget::cmCursesStringWidget(int width, int height,
                                            int left, int top) :
   cmCursesWidget(width, height, left, top)
 {
@@ -63,7 +63,7 @@ void cmCursesStringWidget::OnType(int& key, cmCursesMainForm* fm, WINDOW*)
   form_driver(fm->GetForm(), key);
 }
 
-bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm, 
+bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
                                        WINDOW* w)
 {
   int x,y;
@@ -90,7 +90,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
 
     getmaxyx(stdscr, y, x);
     // If window too small, handle 'q' only
-    if ( x < cmCursesMainForm::MIN_WIDTH  || 
+    if ( x < cmCursesMainForm::MIN_WIDTH  ||
          y < cmCursesMainForm::MIN_HEIGHT )
       {
       // quit
@@ -100,7 +100,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
         }
       else
         {
-        key=getch(); 
+        key=getch();
         continue;
         }
       }
@@ -111,7 +111,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
       return false;
       }
     // 10 == enter
-    if (key == 10 || key == KEY_ENTER) 
+    if (key == 10 || key == KEY_ENTER)
       {
       this->OnReturn(fm, w);
       }
@@ -121,7 +121,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
               key == KEY_PPAGE || key == ctrl('u'))
       {
       this->InEdit = false;
-      delete[] this->OriginalString;     
+      delete[] this->OriginalString;
       // trick to force forms to update the field buffer
       form_driver(form, REQ_NEXT_FIELD);
       form_driver(form, REQ_PREV_FIELD);
@@ -136,8 +136,8 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
         fm->PrintKeys();
         this->SetString(this->OriginalString);
         delete[] this->OriginalString;
-        touchwin(w); 
-        wrefresh(w); 
+        touchwin(w);
+        wrefresh(w);
         return true;
         }
       }
@@ -165,7 +165,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
       {
       form_driver(form, REQ_END_FIELD);
       }
-    else if ( key == 127 || 
+    else if ( key == 127 ||
               key == KEY_BACKSPACE )
       {
       if ( form->curcol > 0 )
@@ -175,7 +175,7 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
       }
     else if ( key == ctrl('d') ||key == KEY_DC )
       {
-      if ( form->curcol > 0 )
+      if ( form->curcol >= 0 )
         {
         form_driver(form, REQ_DEL_CHAR);
         }
@@ -186,10 +186,10 @@ bool cmCursesStringWidget::HandleInput(int& key, cmCursesMainForm* fm,
       }
     if ( !this->Done )
       {
-      touchwin(w); 
-      wrefresh(w); 
-      
-      key=getch(); 
+      touchwin(w);
+      wrefresh(w);
+
+      key=getch();
       }
     }
   return true;
@@ -214,7 +214,7 @@ bool cmCursesStringWidget::PrintKeys()
 {
   int x,y;
   getmaxyx(stdscr, y, x);
-  if ( x < cmCursesMainForm::MIN_WIDTH  || 
+  if ( x < cmCursesMainForm::MIN_WIDTH  ||
        y < cmCursesMainForm::MIN_HEIGHT )
     {
     return false;
