@@ -273,7 +273,7 @@ public:
   // and retVal is return value or exception.
   int RunMakeCommand(const char* command, std::string* output,
     int* retVal, const char* dir, int timeout,
-    std::ofstream& ofs);
+    std::ostream& ofs);
 
   /*
    * return the current tag
@@ -287,10 +287,6 @@ public:
   //source directory, it will become /.../relative/path/to/file
   std::string GetShortPathToFile(const char* fname);
 
-  //! Get the path to CTest
-  const char* GetCTestExecutable() { return this->CTestSelf.c_str(); }
-  const char* GetCMakeExecutable() { return this->CMakeSelf.c_str(); }
-
   enum {
     EXPERIMENTAL,
     NIGHTLY,
@@ -490,8 +486,6 @@ private:
   int                     CompatibilityMode;
 
   // information for the --build-and-test options
-  std::string              CMakeSelf;
-  std::string              CTestSelf;
   std::string              BinaryDir;
 
   std::string              NotesFiles;
@@ -546,9 +540,6 @@ private:
   int GenerateCTestNotesOutput(std::ostream& os,
     const VectorOfStrings& files);
 
-  ///! Find the running cmake
-  void FindRunningCMake();
-
   //! Check if the argument is the one specified
   bool CheckArgument(const std::string& arg, const char* varg1,
     const char* varg2 = 0);
