@@ -74,10 +74,6 @@ bool cmConfigureFileCommand
   this->CopyOnly = false;
   this->EscapeQuotes = false;
 
-  // for CMake 2.0 and earlier CONFIGURE_FILE defaults to the FinalPass,
-  // after 2.0 it only does InitialPass
-  this->Immediate = !this->Makefile->NeedBackwardsCompatibility(2,0);
-
   this->AtOnly = false;
   for(unsigned int i=2;i < args.size();++i)
     {
@@ -101,30 +97,17 @@ bool cmConfigureFileCommand
       }
     else if(args[i] == "IMMEDIATE")
       {
-      this->Immediate = true;
+      /* Ignore legacy option.  */
       }
     }
-  
-  // If we were told to copy the file immediately, then do it on the
-  // first pass (now).
-  if(this->Immediate)
-    {
-    if ( !this->ConfigureFile() )
-      {
-      this->SetError("Problem configuring file");
-      return false;
-      }
-    }
-  
-  return true;
-}
 
-void cmConfigureFileCommand::FinalPass()
-{
-  if(!this->Immediate)
+  if ( !this->ConfigureFile() )
     {
-    this->ConfigureFile();
+    this->SetError("Problem configuring file");
+    return false;
     }
+
+  return true;
 }
 
 int cmConfigureFileCommand::ConfigureFile()
