@@ -13,6 +13,12 @@
 
 #include "cmExternalMakefileProjectGenerator.h"
 
+void cmExternalMakefileProjectGenerator
+::EnableLanguage(std::vector<std::string> const&,
+                 cmMakefile *, bool)
+{
+}
+
 std::string cmExternalMakefileProjectGenerator::CreateFullGeneratorName(
                                                    const char* globalGenerator,
                                                    const char* extraGenerator)
@@ -49,7 +55,7 @@ const char* cmExternalMakefileProjectGenerator::GetGlobalGeneratorName(
     }
 
   // otherwise search for the matching global generator
-  for (std::vector<std::string>::const_iterator 
+  for (std::vector<std::string>::const_iterator
        it = this->SupportedGlobalGenerators.begin();
        it != this->SupportedGlobalGenerators.end();
        ++it)
