@@ -18,7 +18,7 @@
  * \brief Define a command to search for an executable program.
  *
  * cmFindFileCommand is used to define a CMake variable
- * that specifies an executable program. The command searches 
+ * that specifies an executable program. The command searches
  * in the current path (e.g., PATH environment variable) for
  * an executable that matches one of the supplied names.
  */
@@ -29,23 +29,13 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmFindFileCommand;
     }
-  virtual const char* GetName() { return "find_file";}
+  virtual const char* GetName() const { return "find_file";}
 
-  /**
-   * Succinct documentation.
-   */
-  virtual const char* GetTerseDocumentation() 
-    {
-    return "Find the full path to a file.";
-    }
-  
   cmTypeMacro(cmFindFileCommand, cmFindPathCommand);
-protected:
-  virtual void GenerateDocumentation();
 };
 
 
