@@ -39,31 +39,6 @@ public:
    */
   virtual const char* GetName() const { return "get_cmake_property";}
 
-  /**
-   * Succinct documentation.
-   */
-  virtual const char* GetTerseDocumentation() const
-    {
-    return "Get a property of the CMake instance.";
-    }
-
-  /**
-   * Longer documentation.
-   */
-  virtual const char* GetFullDocumentation() const
-    {
-      return
-        "  get_cmake_property(VAR property)\n"
-        "Get a property from the CMake instance.  "
-        "The value of the property is stored in the variable VAR.  "
-        "If the property is not found, VAR will be set to \"NOTFOUND\".  "
-        "Some supported properties "
-        "include: VARIABLES, CACHE_VARIABLES, COMMANDS, MACROS, and "
-        "COMPONENTS."
-        "\n"
-        "See also the more general get_property() command.";
-    }
-
   cmTypeMacro(cmGetCMakePropertyCommand, cmCommand);
 };
 
