@@ -70,11 +70,6 @@ public:
   virtual void GetDocumentation(cmDocumentationEntry& entry) const {
     entry.Name = vs9generatorName;
     entry.Brief = "Generates Visual Studio 9 2008 project files.";
-    entry.Full =
-      "It is possible to append a space followed by the platform name "
-      "to create project files for a specific target platform. E.g. "
-      "\"Visual Studio 9 2008 Win64\" will create project files for "
-      "the x64 processor; \"Visual Studio 9 2008 IA64\" for Itanium.";
   }
 
   virtual void GetGenerators(std::vector<std::string>& names) const {
@@ -106,7 +101,6 @@ cmGlobalVisualStudio9Generator::cmGlobalVisualStudio9Generator(
   : cmGlobalVisualStudio8Generator(name, platformName,
                                    additionalPlatformDefinition)
 {
-  this->FindMakeProgramFile = "CMakeVS9FindMake.cmake";
 }
 
 //----------------------------------------------------------------------------
