@@ -19,7 +19,7 @@
  *
  * cmLinkLibrariesCommand is used to specify a list of libraries to link
  * into executable(s) or shared objects. The names of the libraries
- * should be those defined by the LIBRARY(library) command(s).  
+ * should be those defined by the LIBRARY(library) command(s).
  */
 class cmLinkLibrariesCommand : public cmCommand
 {
@@ -27,7 +27,7 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmLinkLibrariesCommand;
     }
@@ -44,31 +44,6 @@ public:
    */
   virtual const char* GetName() const { return "link_libraries";}
 
-  /**
-   * Succinct documentation.
-   */
-  virtual const char* GetTerseDocumentation() const
-    {
-    return "Deprecated. Use the target_link_libraries() command instead.";
-    }
-  
-  /**
-   * More documentation.
-   */
-  virtual const char* GetFullDocumentation() const
-    {
-    return
-      "Link libraries to all targets added later.\n"
-      "  link_libraries(library1 <debug | optimized> library2 ...)\n"
-      "Specify a list of libraries to be linked into "
-      "any following targets (typically added with the add_executable "
-      "or add_library calls).  This command is passed "
-      "down to all subdirectories.  "
-      "The debug and optimized strings may be used to indicate that "
-      "the next library listed is to be used only for that specific "
-      "type of build.";
-    }
-  
   /** This command is kept for compatibility with older CMake versions. */
   virtual bool IsDiscouraged() const
     {
