@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: hostip.c,v 1.2 2007-03-15 19:22:13 andy Exp $
+ * $Id$
  ***************************************************************************/
 
 #include "setup.h"
@@ -609,7 +609,7 @@ Curl_addrinfo *Curl_ip2addr(in_addr_t num, const char *hostname, int port)
   h = &buf->hostentry;
   h->h_addr_list = &buf->h_addr_list[0];
   addrentry = &buf->addrentry;
-#ifdef _CRAYC
+#ifdef _CRAY
   /* On UNICOS, s_addr is a bit field and for some reason assigning to it
    * doesn't work.  There must be a better fix than this ugly hack.
    */
